summaryrefslogtreecommitdiffstats
path: root/server/log.c
diff options
context:
space:
mode:
authorGraham Leggett <minfrin@apache.org>2011-12-14 01:33:46 +0100
committerGraham Leggett <minfrin@apache.org>2011-12-14 01:33:46 +0100
commitad489c105b6a03587ccf6227c93039822cf7e4d4 (patch)
treece7d7585e222b6bfcb0d13489cefa4978fd23281 /server/log.c
parentFurther clarify the naming of the entity that originates the request by (diff)
downloadapache2-ad489c105b6a03587ccf6227c93039822cf7e4d4.tar.xz
apache2-ad489c105b6a03587ccf6227c93039822cf7e4d4.zip
Further clarify the naming of the entity that originates the request by
calling that entity a useragent instead of a client. git-svn-id: https://svn.apache.org/repos/asf/httpd/httpd/trunk@1214005 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'server/log.c')
-rw-r--r--server/log.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/server/log.c b/server/log.c
index 70c37e0ae7..bdcf427753 100644
--- a/server/log.c
+++ b/server/log.c
@@ -562,8 +562,8 @@ static int log_remote_address(const ap_errorlog_info *info, const char *arg,
char *buf, int buflen)
{
if (info->r && !(arg && *arg == 'c'))
- return apr_snprintf(buf, buflen, "%s:%d", info->r->client_ip,
- info->r->client_addr->port);
+ return apr_snprintf(buf, buflen, "%s:%d", info->r->useragent_ip,
+ info->r->useragent_addr->port);
else if (info->c)
return apr_snprintf(buf, buflen, "%s:%d", info->c->peer_ip,
info->c->peer_addr->port);
@@ -962,13 +962,13 @@ static int do_errorlog_default(const ap_errorlog_info *info, char *buf,
}
/*
* client_ip/peer_ip can be client or backend server. If we have a scoreboard
* handle, it is likely a client.
*/
if (info->r) {
len += apr_snprintf(buf + len, buflen - len,
info->r->connection->sbh ? "[client %s:%d] " : "[remote %s:%d] ",
- info->r->client_ip, info->r->client_addr->port);
+ info->r->useragent_ip, info->r->useragent_addr->port);
}
else if (info->c) {
len += apr_snprintf(buf + len, buflen - len,
@@ -962,13 +962,13 @@ static int do_errorlog_default(const ap_errorlog_info *info, char *buf,
}
/*
- * client_ip/peer_ip can be client or backend server. If we have a scoreboard
- * handle, it is likely a client.
+ * useragent_ip/peer_ip can be client or backend server. If we have
+ * a scoreboard handle, it is likely a client.
*/
if (info->r) {